@@ -5,7 +5,7 @@ use std::pin::Pin;
 #[cfg(feature = "tls-rustls")]
 use std::str::FromStr;
 #[cfg(feature = "gssapi")]
-use std::sync::atomic::AtomicBool;
+use std::sync::RwLock;
 use std::sync::{Arc, Mutex};
 use std::task::{Context, Poll};
 use std::time::Duration;
@@ -92,18 +92,16 @@ lazy_static! {
 #[cfg(all(feature = "gssapi", feature = "tls-rustls"))]
 lazy_static! {
     static ref ENDPOINT_ALG: HashMap<&'static str, &'static Algorithm> = {
-        use maplit::hashmap;
-
-        hashmap! {
-            "1.2.840.113549.1.1.4" => &digest::SHA256,
-            "1.2.840.113549.1.1.5" => &digest::SHA256,
-            "1.2.840.113549.1.1.11" => &digest::SHA256,
-            "1.2.840.113549.1.1.12" => &digest::SHA384,
-            "1.2.840.113549.1.1.13" => &digest::SHA512,
-            "1.2.840.10045.4.3.2" => &digest::SHA256,
-            "1.2.840.10045.4.3.3" => &digest::SHA384,
-            "1.2.840.10045.4.3.4" => &digest::SHA512,
-        }
+        HashMap::from([
+            ("1.2.840.113549.1.1.4", &digest::SHA256),
+            ("1.2.840.113549.1.1.5", &digest::SHA256),
+            ("1.2.840.113549.1.1.11", &digest::SHA256),
+            ("1.2.840.113549.1.1.12", &digest::SHA384),
+            ("1.2.840.113549.1.1.13", &digest::SHA512),
+            ("1.2.840.10045.4.3.2", &digest::SHA256),
+            ("1.2.840.10045.4.3.3", &digest::SHA384),
+            ("1.2.840.10045.4.3.4", &digest::SHA512),
+        ])
     };
 }
 
@@ -405,8 +403,8 @@ impl LdapConnAsync {
             port = url_port;
         }
         let (_hostname, host_port) = match url.host_str() {
-            Some(h) if h != "" => (h, format!("{}:{}", h, port)),
-            Some(h) if h == "" => ("localhost", format!("localhost:{}", port)),
+            Some(h) if !h.is_empty() => (h, format!("{}:{}", h, port)),
+            Some(h) if !h.is_empty() => ("localhost", format!("localhost:{}", port)),
             _ => panic!("unexpected None from url.host_str()"),
         };
         let stream = TcpStream::connect(host_port.as_str()).await?;
@@ -432,7 +430,7 @@ impl LdapConnAsync {
                 }
                 let parts = conn.stream.into_parts();
                 let tls_stream = if let ConnType::Tcp(stream) = parts.io {
-                    LdapConnAsync::create_tls_stream(settings, &_hostname, stream).await?
+                    LdapConnAsync::create_tls_stream(settings, _hostname, stream).await?
                 } else {
                     panic!("underlying stream not TCP");
                 };
@@ -568,12 +566,12 @@ impl LdapConnAsync {
             #[cfg(feature = "gssapi")]
             has_decoded_data: false,
             #[cfg(feature = "gssapi")]
-            sasl_wrap: Arc::new(AtomicBool::new(false)),
+            sasl_param: Arc::new(RwLock::new((false, 0))),
             #[cfg(feature = "gssapi")]
             client_ctx: client_ctx.clone(),
         };
         #[cfg(feature = "gssapi")]
-        let sasl_wrap = codec.sasl_wrap.clone();
+        let sasl_param = codec.sasl_param.clone();
         let (tx, rx) = mpsc::unbounded_channel();
         let (id_scrub_tx, id_scrub_rx) = mpsc::unbounded_channel();
         let conn = LdapConnAsync {
@@ -589,7 +587,7 @@ impl LdapConnAsync {
             tx,
             id_scrub_tx,
             #[cfg(feature = "gssapi")]
-            sasl_wrap,
+            sasl_param,
             #[cfg(feature = "gssapi")]
             client_ctx,
             #[cfg(feature = "gssapi")]
