@@ -6,7 +6,7 @@
 //!
 //! ```toml
 //! [dependencies.ldap3]
-//! version = "0.10.3"
+//! version = "0.10.4"
 //! ```
 //!
 //! ## Summary
@@ -237,6 +237,8 @@ pub use search::{
 };
 #[cfg(feature = "sync")]
 pub use sync::{EntryStream, LdapConn};
+#[allow(deprecated)]
 pub use util::{
-    dn_escape, get_url_params, ldap_escape, ldap_str_unescape, LdapUrlExt, LdapUrlParams,
+    dn_escape, get_url_params, ldap_escape, ldap_str_unescape, ldap_unescape, LdapUrlExt,
+    LdapUrlParams,
 };
